@@ -3,6 +3,7 @@ from typing import Any, List, Optional, Tuple, Union
 
 from ftfy import fix_text
 from number_parser import parse
+from pyquery import PyQuery
 
 from easytxt import config
 
@@ -301,6 +302,9 @@ def to_str(
     default: str = "",
 ) -> str:
 
+    if isinstance(value, PyQuery):
+        value = value.eq(0).text() if value else None
+
     if value is None:
         return default
 
